==> albert_0.27.0.orig.tar.gz: albert-0.27.0/plugins/datetime/i18n/datetime_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ConfigWidget</name>
    <message>
        <source>Show date and time on empty query</source>
        <translation>Datum und Uhrzeit bei leerer Abfrage anzeigen</translation>
    </message>
    <message>
        <source>The &apos;date and time&apos; extension provides the items *date*, *time*, *unix* and *utc*. It also converts unix timestamps (numbers) to local time.</source>
        <translation>Die Erweiterung &apos;Datum und Uhrzeit&apos; bietet die Elemente *datum*, *zeit*, *unix* und *utc*. Sie konvertiert auch Unix-Zeitstempel (Zahlen) in die lokale Zeit.</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <source>Time</source>
        <translation>Zeit</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Unix time</source>
        <translation>Unixzeit</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>In die Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Copy &apos;%1&apos; to clipboard</source>
        <translation>&apos;%1&apos; in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>UTC date and time</source>
        <translation>UTC Datum und Uhrzeit</translation>
    </message>
    <message>
        <source>Date and time from unix time</source>
        <translation>Datum und Uhrzeit aus Unixzeit</translation>
    </message>
</context>
</TS>

==> albert_0.28.0.orig.tar.gz: albert-0.28.0/plugins/datetime/i18n/datetime_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ConfigWidget</name>
    <message>
        <source>Show date and time on empty query</source>
        <translation>Datum und Uhrzeit bei leerer Abfrage anzeigen</translation>
    </message>
    <message>
        <source>The &apos;date and time&apos; extension provides the items *date*, *time*, *unix* and *utc*. It also converts unix timestamps (numbers) to local time.</source>
        <translation>Die Erweiterung &apos;Datum und Uhrzeit&apos; bietet die Elemente *datum*, *zeit*, *unix* und *utc*. Sie konvertiert auch Unix-Zeitstempel (Zahlen) in die lokale Zeit.</translation>
    </message>
</context>
<context>
    <name>DateTimeItemBase</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Unix time</source>
        <translation>Unixzeit</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Zeit</translation>
    </message>
    <message>
        <source>UTC date and time</source>
        <translation>UTC Datum und Uhrzeit</translation>
    </message>
    <message>
        <source>Date and time</source>
        <translation>Datum und Uhrzeit</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Copy and paste</source>
        <translation>Kopieren und einfügen</translation>
    </message>
    <message>
        <source>Date and time from unix time</source>
        <translation>Datum und Uhrzeit aus Unixzeit</translation>
    </message>
</context>
</TS>
